@@ -106,17 +106,8 @@ def main(args):
 
     records = ({k: p.get(k) for k in keys} for p in path_it)
 
-    dumps: Callable[..., bytes]
+    from orjson import dumps
     if output_type in ("log", "json"):
-        try:
-            from orjson import dumps
-        except ImportError:
-            odumps: Callable[..., str]
-            try:
-                from ujson import dumps as odumps
-            except ImportError:
-                from json import dumps as odumps
-            dumps = lambda obj: bytes(odumps(obj, ensure_ascii=False), "utf-8")
         if output_file:
             write = file.buffer.write
         else:
