@@ -103,21 +103,18 @@ class AlistUploadTaskList:
     ):
         "清空任务列表"
         def gen_step():
-            undone = yield partial(
-                self.list, 
+            undone = yield self.list(
                 async_=async_, 
                 **request_kwargs, 
             )
             tids = [t["id"] for t in undone]
             if tids:
-                yield partial(
-                    self.cancel, 
+                yield self.cancel(
                     tids, 
                     async_=async_, 
                     **request_kwargs, 
                 )
-            yield partial(
-                self.clear_done, 
+            yield self.clear_done(
                 async_=async_, 
                 **request_kwargs, 
             )
@@ -232,8 +229,7 @@ class AlistUploadTaskList:
     ):
         "获取某个任务信息"
         def gen_step():
-            resp = yield partial(
-                self.client.task_info, 
+            resp = yield self.client.task_info(
                 tid, 
                 category=type(self).__category__, 
                 request=self.async_request if async_ else self.request, 
@@ -270,8 +266,7 @@ class AlistUploadTaskList:
         **request_kwargs, 
     ) -> int | Coroutine[Any, Any, int]:
         def gen_step():
-            ls = yield partial(
-                self.list, 
+            ls = yield self.list(
                 async_=async_, 
                 **request_kwargs, 
             )
@@ -304,8 +299,7 @@ class AlistUploadTaskList:
         **request_kwargs, 
     ) -> bool | Coroutine[Any, Any, bool]:
         def gen_step():
-            resp = yield partial(
-                self.get, 
+            resp = yield self.get(
                 tid, 
                 async_=async_, 
                 **request_kwargs, 
@@ -368,8 +362,7 @@ class AlistUploadTaskList:
     ) -> list[dict] | Coroutine[Any, Any, list[dict]]:
         "列出所有已完成任务"
         def gen_step():
-            resp = yield partial(
-                self.client.task_done, 
+            resp = yield self.client.task_done(
                 category=type(self).__category__, 
                 request=self.async_request if async_ else self.request, 
                 async_=async_, 
@@ -402,8 +395,7 @@ class AlistUploadTaskList:
     ) -> list[dict] | Coroutine[Any, Any, list[dict]]:
         "列出所有未完成任务"
         def gen_step():
-            resp = yield partial(
-                self.client.task_undone, 
+            resp = yield self.client.task_undone(
                 category=type(self).__category__, 
                 request=self.async_request if async_ else self.request, 
                 async_=async_, 
@@ -439,18 +431,16 @@ class AlistUploadTaskList:
     ) -> dict | Coroutine[Any, Any, dict]:
         "删除某个任务（先取消再删除）"
         def gen_step():
-            yield partial(
-                self.cancel, 
+            yield self.cancel(
                 tid, 
                 async_=async_, 
                 **request_kwargs, 
             )
-            return (yield partial(
-                self.delete, 
+            return self.delete(
                 tid, 
                 async_=async_, 
                 **request_kwargs, 
-            ))
+            )
         return run_gen_step(gen_step, async_)
 
     @overload
@@ -545,13 +535,11 @@ class AlistUploadTaskList:
     ) -> list[dict] | Coroutine[Any, Any, list[dict]]:
         "列出所有任务"
         def gen_step():
-            undone = yield partial(
-                self.list_undone, 
+            undone = yield self.list_undone(
                 async_=async_, 
                 **request_kwargs, 
             )
-            tasks = yield partial(
-                self.list_done, 
+            tasks = yield self.list_done(
                 async_=async_, 
                 **request_kwargs, 
             )
